[libpng15] Imported from libpng-1.5.18rc02.tar
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 8ffb612..b7e6a88 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -217,7 +217,7 @@
 # SET UP LINKS
 if(PNG_SHARED)
   set_target_properties(${PNG_LIB_NAME} PROPERTIES
-#   VERSION 15.${PNGLIB_RELEASE}.1.5.18rc01
+#   VERSION 15.${PNGLIB_RELEASE}.1.5.18rc02
     VERSION 15.${PNGLIB_RELEASE}.0
     SOVERSION 15
     CLEAN_DIRECT_OUTPUT 1)
diff --git a/LICENSE b/LICENSE
index ce55bd3..42d2927 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.18rc01, January 28, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.18rc02, January 30, 2014, are
 Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 28, 2014
+January 30, 2014
diff --git a/README b/README
index 2074f62..69d5d86 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.18rc01 - January 28, 2014 (shared library 15.0)
+README for libpng version 1.5.18rc02 - January 30, 2014 (shared library 15.0)
 See the note about version numbers near the top of png.h
 
 See INSTALL for instructions on how to install libpng.
diff --git a/configure b/configure
index 258ba3b..6e56bee 100755
--- a/configure
+++ b/configure
@@ -1,6 +1,6 @@
 #! /bin/sh
 # Guess values for system-dependent variables and create Makefiles.
-# Generated by GNU Autoconf 2.69 for libpng 1.5.18rc01.
+# Generated by GNU Autoconf 2.69 for libpng 1.5.18rc02.
 #
 # Report bugs to <png-mng-implement@lists.sourceforge.net>.
 #
@@ -590,8 +590,8 @@
 # Identity of this package.
 PACKAGE_NAME='libpng'
 PACKAGE_TARNAME='libpng'
-PACKAGE_VERSION='1.5.18rc01'
-PACKAGE_STRING='libpng 1.5.18rc01'
+PACKAGE_VERSION='1.5.18rc02'
+PACKAGE_STRING='libpng 1.5.18rc02'
 PACKAGE_BUGREPORT='png-mng-implement@lists.sourceforge.net'
 PACKAGE_URL=''
 
@@ -1351,7 +1351,7 @@
   # Omit some internal or obsolete options to make the list less imposing.
   # This message is too long to be a string in the A/UX 3.1 sh.
   cat <<_ACEOF
-\`configure' configures libpng 1.5.18rc01 to adapt to many kinds of systems.
+\`configure' configures libpng 1.5.18rc02 to adapt to many kinds of systems.
 
 Usage: $0 [OPTION]... [VAR=VALUE]...
 
@@ -1421,7 +1421,7 @@
 
 if test -n "$ac_init_help"; then
   case $ac_init_help in
-     short | recursive ) echo "Configuration of libpng 1.5.18rc01:";;
+     short | recursive ) echo "Configuration of libpng 1.5.18rc02:";;
    esac
   cat <<\_ACEOF
 
@@ -1571,7 +1571,7 @@
 test -n "$ac_init_help" && exit $ac_status
 if $ac_init_version; then
   cat <<\_ACEOF
-libpng configure 1.5.18rc01
+libpng configure 1.5.18rc02
 generated by GNU Autoconf 2.69
 
 Copyright (C) 2012 Free Software Foundation, Inc.
@@ -1994,7 +1994,7 @@
 This file contains any messages produced by compilers while
 running configure, to aid debugging if configure makes a mistake.
 
-It was created by libpng $as_me 1.5.18rc01, which was
+It was created by libpng $as_me 1.5.18rc02, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   $ $0 $@
@@ -2857,7 +2857,7 @@
 
 # Define the identity of the package.
  PACKAGE='libpng'
- VERSION='1.5.18rc01'
+ VERSION='1.5.18rc02'
 
 
 cat >>confdefs.h <<_ACEOF
@@ -2973,7 +2973,7 @@
 
 
 
-PNGLIB_VERSION=1.5.18rc01
+PNGLIB_VERSION=1.5.18rc02
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=18
@@ -13628,7 +13628,7 @@
 # report actual input values of CONFIG_FILES etc. instead of their
 # values after options handling.
 ac_log="
-This file was extended by libpng $as_me 1.5.18rc01, which was
+This file was extended by libpng $as_me 1.5.18rc02, which was
 generated by GNU Autoconf 2.69.  Invocation command line was
 
   CONFIG_FILES    = $CONFIG_FILES
@@ -13694,7 +13694,7 @@
 cat >>$CONFIG_STATUS <<_ACEOF || ac_write_fail=1
 ac_cs_config="`$as_echo "$ac_configure_args" | sed 's/^ //; s/[\\""\`\$]/\\\\&/g'`"
 ac_cs_version="\\
-libpng config.status 1.5.18rc01
+libpng config.status 1.5.18rc02
 configured by $0, generated by GNU Autoconf 2.69,
   with options \\"\$ac_cs_config\\"
 
diff --git a/configure.ac b/configure.ac
index e60ba3c..d3b96ce 100644
--- a/configure.ac
+++ b/configure.ac
@@ -18,12 +18,12 @@
 
 dnl Version number stuff here:
 
-AC_INIT([libpng], [1.5.18rc01], [png-mng-implement@lists.sourceforge.net])
+AC_INIT([libpng], [1.5.18rc02], [png-mng-implement@lists.sourceforge.net])
 AM_INIT_AUTOMAKE([1.13 serial-tests subdir-objects])
 dnl stop configure from automagically running automake
 AM_MAINTAINER_MODE
 
-PNGLIB_VERSION=1.5.18rc01
+PNGLIB_VERSION=1.5.18rc02
 PNGLIB_MAJOR=1
 PNGLIB_MINOR=5
 PNGLIB_RELEASE=18
diff --git a/libpng-manual.txt b/libpng-manual.txt
index 53395b5..d72dafc 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.18rc01 - January 28, 2014
+ libpng version 1.5.18rc02 - January 30, 2014
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.18rc01 - January 28, 2014
+ libpng versions 0.97, January 1998, through 1.5.18rc02 - January 30, 2014
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
 
@@ -4667,13 +4667,13 @@
 
 XIV. Y2K Compliance in libpng
 
-January 28, 2014
+January 30, 2014
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.18rc01 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.18rc02 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has two year fields.  One is a 2-byte unsigned integer that
diff --git a/libpng.3 b/libpng.3
index c583707..83d9a4e 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,6 +1,6 @@
-.TH LIBPNG 3 "January 28, 2014"
+.TH LIBPNG 3 "January 30, 2014"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.18rc01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.18rc02
 .SH SYNOPSIS
 \fB
 #include <png.h>\fP
@@ -492,7 +492,7 @@
 .SH LIBPNG.TXT
 Libpng-manual.txt - A description on how to use and modify libpng
 
- libpng version 1.5.18rc01 - January 28, 2014
+ libpng version 1.5.18rc02 - January 30, 2014
  Updated and distributed by Glenn Randers-Pehrson
  <glennrp at users.sourceforge.net>
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
@@ -503,7 +503,7 @@
 
  Based on:
 
- libpng versions 0.97, January 1998, through 1.5.18rc01 - January 28, 2014
+ libpng versions 0.97, January 1998, through 1.5.18rc02 - January 30, 2014
  Updated and distributed by Glenn Randers-Pehrson
  Copyright (c) 1998-2013 Glenn Randers-Pehrson
 
@@ -5160,13 +5160,13 @@
 
 .SH XIV. Y2K Compliance in libpng
 
-January 28, 2014
+January 30, 2014
 
 Since the PNG Development group is an ad-hoc body, we can't make
 an official declaration.
 
 This is your unofficial assurance that libpng from version 0.71 and
-upward through 1.5.18rc01 are Y2K compliant.  It is my belief that earlier
+upward through 1.5.18rc02 are Y2K compliant.  It is my belief that earlier
 versions were also Y2K compliant.
 
 Libpng only has two year fields.  One is a 2-byte unsigned integer that
@@ -5399,7 +5399,7 @@
  1.5.17rc01-03       15    10517  15.so.15.17[.0]
  1.5.17              15    10517  15.so.15.17[.0]
  1.5.18beta01-05     15    10518  15.so.15.18[.0]
- 1.5.18rc01          15    10518  15.so.15.18[.0]
+ 1.5.18rc01-rc02     15    10518  15.so.15.18[.0]
 
 Henceforth the source version will match the shared-library minor
 and patch numbers; the shared-library major version number will be
@@ -5456,7 +5456,7 @@
 
 Thanks to Frank J. T. Wojcik for helping with the documentation.
 
-Libpng version 1.5.18rc01 - January 28, 2014:
+Libpng version 1.5.18rc02 - January 30, 2014:
 Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
 Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
 
@@ -5479,7 +5479,7 @@
 
 This code is released under the libpng license.
 
-libpng versions 1.2.6, August 15, 2004, through 1.5.18rc01, January 28, 2014, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.18rc02, January 30, 2014, are
 Copyright (c) 2004,2006-2007 Glenn Randers-Pehrson, and are
 distributed according to the same disclaimer and license as libpng-1.2.5
 with the following individual added to the list of Contributing Authors
@@ -5578,7 +5578,7 @@
 
 Glenn Randers-Pehrson
 glennrp at users.sourceforge.net
-January 28, 2014
+January 30, 2014
 
 .\" end of man page
 
diff --git a/libpngpf.3 b/libpngpf.3
index dbd3b92..03b9227 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,6 +1,6 @@
-.TH LIBPNGPF 3 "January 28, 2014"
+.TH LIBPNGPF 3 "January 30, 2014"
 .SH NAME
-libpng \- Portable Network Graphics (PNG) Reference Library 1.5.18rc01
+libpng \- Portable Network Graphics (PNG) Reference Library 1.5.18rc02
 (private functions)
 .SH SYNOPSIS
 \fB#include \fI"pngpriv.h"
diff --git a/png.5 b/png.5
index bb069a7..80a6ffc 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "January 28, 2014"
+.TH PNG 5 "January 30, 2014"
 .SH NAME
 png \- Portable Network Graphics (PNG) format
 .SH DESCRIPTION
diff --git a/png.c b/png.c
index 4cc02fc..8abe778 100644
--- a/png.c
+++ b/png.c
@@ -14,7 +14,7 @@
 #include "pngpriv.h"
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_18rc01 Your_png_h_is_not_version_1_5_18rc01;
+typedef png_libpng_version_1_5_18rc02 Your_png_h_is_not_version_1_5_18rc02;
 
 /* Tells libpng that we have already handled the first "num_bytes" bytes
  * of the PNG file signature.  If the PNG data is embedded into another
@@ -658,13 +658,13 @@
 #else
 #  ifdef __STDC__
    return PNG_STRING_NEWLINE \
-     "libpng version 1.5.18rc01 - January 28, 2014" PNG_STRING_NEWLINE \
+     "libpng version 1.5.18rc02 - January 30, 2014" PNG_STRING_NEWLINE \
      "Copyright (c) 1998-2014 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
      "Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
      "Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
      PNG_STRING_NEWLINE;
 #  else
-      return "libpng version 1.5.18rc01 - January 28, 2014\
+      return "libpng version 1.5.18rc02 - January 30, 2014\
       Copyright (c) 1998-2014 Glenn Randers-Pehrson\
       Copyright (c) 1996-1997 Andreas Dilger\
       Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index cb06dbc..324723c 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
 
 /* pngconf.h - machine configurable file for libpng
  *
- * libpng version 1.5.18rc01 - January 28, 2014
+ * libpng version 1.5.18rc02 - January 30, 2014
  *
  * Copyright (c) 1998-2013 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngtest.c b/pngtest.c
index 281b0dd..6e6c17a 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1990,4 +1990,4 @@
 #endif
 
 /* Generate a compiler error if there is an old png.h in the search path. */
-typedef png_libpng_version_1_5_18rc01 Your_png_h_is_not_version_1_5_18rc01;
+typedef png_libpng_version_1_5_18rc02 Your_png_h_is_not_version_1_5_18rc02;
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index c4d4813..887e17a 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
 
 VisualStudio instructions
 
-libpng version 1.5.18rc01 - January 28, 2014
+libpng version 1.5.18rc02 - January 30, 2014
 
 Copyright (c) 1998-2010 Glenn Randers-Pehrson
 
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 11eb1c5..f0ba27f 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
 <!--
  * zlib.props - location of zlib source
  *
- * libpng version 1.5.18rc01 - January 28, 2014
+ * libpng version 1.5.18rc02 - January 30, 2014
  *
  * Copyright (c) 1998-2011 Glenn Randers-Pehrson
  *
diff --git a/scripts/README.txt b/scripts/README.txt
index 83dcc61..37a2866 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,9 +1,9 @@
 
-Makefiles for  libpng version 1.5.18rc01 - January 28, 2014
+Makefiles for  libpng version 1.5.18rc02 - January 30, 2014
 
 pnglibconf.h.prebuilt       =>  Stores configuration settings
  makefile.linux    =>  Linux/ELF makefile
-                       (gcc, creates libpng15.so.15.1.5.18rc01)
+                       (gcc, creates libpng15.so.15.1.5.18rc02)
  makefile.gcc      =>  Generic makefile (gcc, creates static libpng.a)
  makefile.knr      =>  Archaic UNIX Makefile that converts files with
                        ansi2knr (Requires ansi2knr.c from
@@ -21,7 +21,7 @@
  makefile.dec      =>  DEC Alpha UNIX makefile
  makefile.dj2      =>  DJGPP 2 makefile
  makefile.elf      =>  Linux/ELF makefile symbol versioning,
-                       (gcc, creates libpng15.so.15.1.5.18rc01)
+                       (gcc, creates libpng15.so.15.1.5.18rc02)
  makefile.freebsd  =>  FreeBSD makefile
  makefile.gcc      =>  Generic gcc makefile
  makefile.hpgcc    =>  HPUX makefile using gcc
@@ -36,12 +36,12 @@
  makefile.os2      =>  OS/2 Makefile (gcc and emx, requires libpng.def)
  makefile.sco      =>  For SCO OSr5  ELF and Unixware 7 with Native cc
  makefile.sggcc    =>  Silicon Graphics (gcc,
-                       creates libpng15.so.15.1.5.18rc01)
+                       creates libpng15.so.15.1.5.18rc02)
  makefile.sgi      =>  Silicon Graphics IRIX makefile (cc, creates static lib)
  makefile.solaris  =>  Solaris 2.X makefile (gcc,
-                       creates libpng15.so.15.1.5.18rc01)
+                       creates libpng15.so.15.1.5.18rc02)
  makefile.so9      =>  Solaris 9 makefile (gcc,
-                       creates libpng15.so.15.1.5.18rc01)
+                       creates libpng15.so.15.1.5.18rc02)
  makefile.std      =>  Generic UNIX makefile (cc, creates static libpng.a)
  makefile.sunos    =>  Sun makefile
  makefile.32sunu   =>  Sun Ultra 32-bit makefile
diff --git a/scripts/libpng-config-head.in b/scripts/libpng-config-head.in
index 660d9e5..8478710 100755
--- a/scripts/libpng-config-head.in
+++ b/scripts/libpng-config-head.in
@@ -11,7 +11,7 @@
 
 # Modeled after libxml-config.
 
-version=1.5.18rc01
+version=1.5.18rc02
 prefix=""
 libdir=""
 libs=""
diff --git a/scripts/libpng.pc.in b/scripts/libpng.pc.in
index 10a6896..764123b 100644
--- a/scripts/libpng.pc.in
+++ b/scripts/libpng.pc.in
@@ -5,6 +5,6 @@
 
 Name: libpng
 Description: Loads and saves PNG files
-Version: 1.5.18rc01
+Version: 1.5.18rc02
 Libs: -L${libdir} -lpng15
 Cflags: -I${includedir}
diff --git a/scripts/makefile.ne12bsd b/scripts/makefile.ne12bsd
index 2a269d7..955913f 100644
--- a/scripts/makefile.ne12bsd
+++ b/scripts/makefile.ne12bsd
@@ -17,7 +17,7 @@
 
 LIB=	png15
 SHLIB_MAJOR=	0
-SHLIB_MINOR=	1.5.18rc01
+SHLIB_MINOR=	1.5.18rc02
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.netbsd b/scripts/makefile.netbsd
index 826e147..315397c 100644
--- a/scripts/makefile.netbsd
+++ b/scripts/makefile.netbsd
@@ -17,7 +17,7 @@
 
 LIB=	png
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.18rc01
+SHLIB_MINOR=	1.5.18rc02
 SRCS=	png.c pngset.c pngget.c pngrutil.c pngtrans.c pngwutil.c \
 	pngread.c pngrio.c pngwio.c pngwrite.c pngrtran.c \
 	pngwtran.c pngmem.c pngerror.c pngpread.c
diff --git a/scripts/makefile.openbsd b/scripts/makefile.openbsd
index c7d91f0..50ddd53 100644
--- a/scripts/makefile.openbsd
+++ b/scripts/makefile.openbsd
@@ -11,7 +11,7 @@
 MANDIR= ${PREFIX}/man/cat
 
 SHLIB_MAJOR=	15
-SHLIB_MINOR=	1.5.18rc01
+SHLIB_MINOR=	1.5.18rc02
 
 LIB=	png
 SRCS=	png.c pngerror.c pngget.c pngmem.c pngpread.c \
diff --git a/scripts/pnglibconf.h.prebuilt b/scripts/pnglibconf.h.prebuilt
index 2f88e46..e0d2d70 100644
--- a/scripts/pnglibconf.h.prebuilt
+++ b/scripts/pnglibconf.h.prebuilt
@@ -1,7 +1,7 @@
-/* 1.5.18rc01 STANDARD API DEFINITION */
+/* 1.5.18rc02 STANDARD API DEFINITION */
 /* pnglibconf.h - library build configuration */
 
-/* libpng version 1.5.18rc01 - January 28, 2014 */
+/* libpng version 1.5.18rc02 - January 30, 2014 */
 
 /* Copyright (c) 1998-2013 Glenn Randers-Pehrson */
 
diff --git a/scripts/symbols.def b/scripts/symbols.def
index dd0fd77..5137033 100644
--- a/scripts/symbols.def
+++ b/scripts/symbols.def
@@ -1,4 +1,4 @@
-;Version 1.5.18rc01
+;Version 1.5.18rc02
 ;--------------------------------------------------------------
 ; LIBPNG symbol list as a Win32 DEF file
 ; Contains all the symbols that can be exported from libpng
diff --git a/png.h b/png.h
index f169ff3..e4d1b28 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
 
 /* png.h - header file for PNG reference library
  *
  * libpng version 1.5.18rc01 - January 28, 2014
  * Copyright (c) 1998-2014 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
  * (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -11,7 +11,7 @@
  * Authors and maintainers:
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
  *   libpng versions 0.97, January 1998, through 1.5.18rc01 - January 28, 2014: Glenn
  *   See also "Contributing Authors", below.
  *
  * Note about libpng version numbers:
@@ -194,7 +194,7 @@
  *    1.5.17rc01-03           15    10517  15.so.15.17[.0]
  *    1.5.17                  15    10517  15.so.15.17[.0]
  *    1.5.18beta01-05         15    10518  15.so.15.18[.0]
- *    1.5.18rc01              15    10518  15.so.15.18[.0]
+ *    1.5.18rc01-rc02         15    10518  15.so.15.18[.0]
  *
  *   Henceforth the source version will match the shared-library major
  *   and minor numbers; the shared-library major version number will be
@@ -226,7 +226,7 @@
  *
  * This code is released under the libpng license.
  *
  * libpng versions 1.2.6, August 15, 2004, through 1.5.18rc01, January 28, 2014, are
  * Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
  * with the following individual added to the list of Contributing Authors:
@@ -338,13 +338,13 @@
  * Y2K compliance in libpng:
  * =========================
  *
- *    January 28, 2014
+ *    January 30, 2014
  *
  *    Since the PNG Development group is an ad-hoc body, we can't make
  *    an official declaration.
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
  *    upward through 1.5.18rc01 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *
  *    Libpng only has two year fields.  One is a 2-byte unsigned integer
@@ -403,9 +403,9 @@
  */
 
 /* Version information for png.h - this should match the version in png.c */
-#define PNG_LIBPNG_VER_STRING "1.5.18rc01"
+#define PNG_LIBPNG_VER_STRING "1.5.18rc02"
 #define PNG_HEADER_VERSION_STRING \
-     " libpng version 1.5.18rc01 - January 28, 2014\n"
+     " libpng version 1.5.18rc02 - January 30, 2014\n"
 
 #define PNG_LIBPNG_VER_SONUM   15
 #define PNG_LIBPNG_VER_DLLNUM  15
@@ -419,7 +419,7 @@
  * PNG_LIBPNG_VER_STRING, omitting any leading zero:
  */
 
-#define PNG_LIBPNG_VER_BUILD  01
+#define PNG_LIBPNG_VER_BUILD  02
 
 /* Release Status */
 #define PNG_LIBPNG_BUILD_ALPHA    1
@@ -566,7 +566,7 @@
 /* This triggers a compiler error in png.c, if png.c and png.h
  * do not agree upon the version number.
  */
-typedef char* png_libpng_version_1_5_18rc01;
+typedef char* png_libpng_version_1_5_18rc02;
 
 /* Three color definitions.  The order of the red, green, and blue, (and the
  * exact size) is not important, although the size of the fields need to
@@ -1,7 +1,7 @@
 /* png.h - header file for PNG reference library
  *
- * libpng version 1.5.18rc01 - January 28, 2014
+ * libpng version 1.5.18rc02 - January 30, 2014
  * Copyright (c) 1998-2014 Glenn Randers-Pehrson
  * (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -11,7 +11,7 @@
  *   libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
  *   libpng versions 0.89c, June 1996, through 0.96, May 1997: Andreas Dilger
- *   libpng versions 0.97, January 1998, through 1.5.18rc01 - January 28, 2014: Glenn
+ *   libpng versions 0.97, January 1998, through 1.5.18rc02 - January 30, 2014: Glenn
  *   See also "Contributing Authors", below.
  *
@@ -226,7 +226,7 @@
  * This code is released under the libpng license.
  *
- * libpng versions 1.2.6, August 15, 2004, through 1.5.18rc01, January 28, 2014, are
+ * libpng versions 1.2.6, August 15, 2004, through 1.5.18rc02, January 30, 2014, are
  * Copyright (c) 2004, 2006-2014 Glenn Randers-Pehrson, and are
  * distributed according to the same disclaimer and license as libpng-1.2.5
@@ -338,13 +338,13 @@
  *
  *    This is your unofficial assurance that libpng from version 0.71 and
- *    upward through 1.5.18rc01 are Y2K compliant.  It is my belief that
+ *    upward through 1.5.18rc02 are Y2K compliant.  It is my belief that
  *    earlier versions were also Y2K compliant.
  *